<?php defined('SYSPATH') or die('No direct script access.');

/**
 * Class Model_Teacher
 *
 * @property $ID                  int
 * @property $LastName            string
 * @property $FirstName           string
 * @property $SecondName          string
 * @property $AccountID           int
 * @property $TeacherID           int
 * @property $JobPositionID       int
 * @property $JobPositionName     string
 * @property $DepID               int
 * @property $DepName             string
 * @property $FacultyID           int
 * @property $FacultyName         string
 * @property $FacultyAbbr         string
 */
class Model_Teacher extends Model_Container
{
    protected function getRawData($id) {
        $sql = 'CALL `Teacher_GetInfo`(:id)';
        $info = DB::query(Database::SELECT, $sql)
            ->param(':id', $id)->execute();

        if ($info->count() == 0)
            throw new InvalidArgumentException('Teacher with not found');
        return $info[0];
    }

    # todo: conflict with self::load()
    public static function with($id) {
        return self::load($id);
    }


    protected function create() {
        // TODO: Implement create() method.
        throw new BadMethodCallException('Method is not implemented yet!');
    }


    public function changeInfo($lastName, $firstName, $secondName, $degreeID, $departmentID) {
        $sql = "SELECT `ChangeTeacherInfo`(:id, :last, :first, :second, :degree, :department) AS `Num`";
        $res = DB::query(Database::SELECT, $sql)
            ->parameters([
                ':id'         => $this->ID,
                ':last'       => $lastName,
                ':first'      => $firstName,
                ':second'     => $secondName,
                ':degree'     => $degreeID,
                ':department' => $departmentID,
            ])->execute()->get('Num');
        return ($res == 0);
    }

    /** @return Model_Discipline[] */
    public function getDisciplines() {
        $semesterID = User::instance()->SemesterID;
        $sql = "CALL `GetDisciplinesForTeacher`(:id, :semesterID)";
        $query = DB::query(Database::SELECT, $sql)
            ->param(':semesterID', $semesterID)
            ->param(':id', $this->ID)
            ->execute();

        $list = [];
        foreach ($query as $data)
            $list[] = new Model_Discipline($data, true);

        return $list;
    }

    /**
     * Get edit rights for discipline.
     * @param $discipline Model_Discipline
     * @return int  1 if teacher is bound to discipline,
     *                    0 if he is from a dean office,
     *                    -1 otherwise.
     */
    public function getRightsForDiscipline(Model_Discipline $discipline) {
        $sql = "SELECT `GetEditRightsForTeacher`(:teacher, :discipline) AS `Num`";
        return DB::query(Database::SELECT, $sql)
            ->param(':discipline', $discipline->ID)
            ->param(':teacher', $this->ID)
            ->execute()->get('Num');
    }
}
